==> core-1.0.1-20160609.142523-8-sources.jar: com/imcode/imcms/addon/imagearchive/entity/LibraryRoles.java <==
package com.imcode.imcms.addon.imagearchive.entity;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 * Created by Serhii from Ubrainians for Imcode
 * on 08.06.16.
 */
@Entity
@Table(name = "archive_library_roles")
@IdClass(LibraryRolesPK.class)
public class LibraryRoles implements Serializable {

	private static final long serialVersionUID = 7183874632512318668L;

	@Id
	private int libraryId;

	@ManyToOne(cascade = CascadeType.ALL)
	@JoinColumn(name="library_id", insertable = false, updatable = false, nullable = false)
	private Library library;

	@Id
	@Column(name = "role_id", nullable = false)
	private int roleId;

	@ManyToOne
	@JoinColumn(name="role_id", referencedColumnName="role_id", insertable=false, updatable=false)
	private Role role;

	@Column(name = "permissions", nullable = false)
	private int permissions;

	@Column(name = "created_dt", nullable = false)
	@Temporal(TemporalType.TIMESTAMP)
	private Date createdDate;

	@Column(name = "updated_dt", nullable = false)
	@Temporal(TemporalType.TIMESTAMP)
	private Date updatedDate;

	@Column(name = "canUse", nullable = false)
	private Boolean canUse;

	@Column(name = "canChange", nullable = false)
	private Boolean canChange;

	public LibraryRoles() {
	}

	public int getLibraryId() {
		return libraryId;
	}

	public void setLibraryId(int libraryId) {
		this.libraryId = libraryId;
	}

	public int getRoleId() {
		return roleId;
	}

	public void setRoleId(int roleId) {
		this.roleId = roleId;
	}

	public int getPermissions() {
		return permissions;
	}

	public void setPermissions(int permissions) {
		this.permissions = permissions;
	}

	public Date getCreatedDate() {
		return createdDate;
	}

	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}

	public Date getUpdatedDate() {
		return updatedDate;
	}

	public void setUpdatedDate(Date updatedDate) {
		this.updatedDate = updatedDate;
	}

	public Boolean getCanUse() {
		return canUse;
	}

	public void setCanUse(Boolean canUse) {
		this.canUse = canUse;
	}

	public Boolean getCanChange() {
		return canChange;
	}

	public void setCanChange(Boolean canChange) {
		this.canChange = canChange;
	}

	public Library getLibrary() {
		return library;
	}

	public void setLibrary(Library library) {
		this.library = library;
	}

	public Role getRole() {
		return role;
	}

	public void setRole(Role role) {
		this.role = role;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}

		if (getClass() != obj.getClass()) {
			return false;
		}

		final LibraryRoles other = (LibraryRoles) obj;
		if (this.libraryId != other.libraryId) {
			return false;
		}

		return this.roleId == other.roleId;
	}

	@Override
	public int hashCode() {
		int hash = 3;
		hash = 48 * hash + this.libraryId + 33 * hash + this.roleId;

		return hash;
	}

	@Override
	public String toString() {
		return String.format("com.imcode.imcms.addon.imagearchive.entity.LibraryRoles[libraryId: %d, roleId: %d]",
				libraryId, roleId);
	}
}

==> core-1.0.1-20160915.153216-44-sources.jar: com/imcode/imcms/addon/imagearchive/entity/LibraryRoles.java <==
package com.imcode.imcms.addon.imagearchive.entity;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

@SuppressWarnings("unused")
@Entity
@Table(name = "archive_library_roles")
public class LibraryRoles implements Serializable {

	private static final long serialVersionUID = 7183874632512318668L;

	@Id
	@Column(name="library_id")
	private int libraryId;

	@Column(name = "role_id", nullable = false)
	private int roleId;

	@Column(name = "permissions", nullable = false)
	private int permissions;

	@Column(name = "created_dt", nullable = false)
	@Temporal(TemporalType.TIMESTAMP)
	private Date createdDate;

	@Column(name = "updated_dt", nullable = false)
	@Temporal(TemporalType.TIMESTAMP)
	private Date updatedDate;

	@Column(name = "canUse", nullable = false)
	private Boolean canUse;

	@Column(name = "canChange", nullable = false)
	private Boolean canChange;

	public LibraryRoles() {
	}

	public int getRoleId() {
		return roleId;
	}

	public void setRoleId(int roleId) {
		this.roleId = roleId;
	}

	public int getPermissions() {
		return permissions;
	}

	public void setPermissions(int permissions) {
		this.permissions = permissions;
	}

	public Date getCreatedDate() {
		return createdDate;
	}

	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}

	public Date getUpdatedDate() {
		return updatedDate;
	}

	public void setUpdatedDate(Date updatedDate) {
		this.updatedDate = updatedDate;
	}

	public Boolean getCanUse() {
		return canUse;
	}

	public void setCanUse(Boolean canUse) {
		this.canUse = canUse;
	}

	public Boolean getCanChange() {
		return canChange;
	}

	public void setCanChange(Boolean canChange) {
		this.canChange = canChange;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}

		if (getClass() != obj.getClass()) {
			return false;
		}

		final LibraryRoles other = (LibraryRoles) obj;
		if (this.libraryId != other.libraryId) {
			return false;
		}

		return this.roleId == other.roleId;
	}

	@Override
	public int hashCode() {
		int hash = 3;
		hash = 48 * hash + this.libraryId + 33 * hash + this.roleId;

		return hash;
	}

	@Override
	public String toString() {
		return String.format("com.imcode.imcms.addon.imagearchive.entity.LibraryRoles[libraryId: %d, roleId: %d]",
				libraryId, roleId);
	}

	public int getLibraryId() {
		return libraryId;
	}

	public void setLibraryId(int libraryId) {
		this.libraryId = libraryId;
	}
}
